@@ -1,9 +1,9 @@
 package Benchmark::Perl::Formance;
-BEGIN {
-  $Benchmark::Perl::Formance::AUTHORITY = 'cpan:SCHWIGON';
-}
+# git description: v0.49-2-g4b6a839
+
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Perl 5 performance benchmarking framework
-$Benchmark::Perl::Formance::VERSION = '0.49';
+$Benchmark::Perl::Formance::VERSION = '0.50';
 use 5.008;
 
 use warnings;
@@ -783,8 +783,7 @@ sub print_outstyle_summary
 
         foreach (sort @run_plugins) {
                 no strict 'refs'; ## no critic
-                my @resultkeys = split(/\./);
-                my ($res) = dpath("/results/".join("/", map { qq("$_") } @resultkeys)."/Benchmark/*[0]")->match($RESULTS);
+                my $res = $self->_plugin_results($_, $RESULTS);
                 $output .= sprintf("%-${len}s : %f\n", join(".", $metric_prefix, $_), ($res || 0));
         }
         return $output;
@@ -914,7 +913,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
